<?php
/**
 * Copyright 2012-2014 Rackspace US, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace OpenCloud\ObjectStore\Exception;

class ObjectNotFoundException extends \RuntimeException
{
    public static function factory($name, \Exception $exception)
    {
        $message = sprintf(
            "%s could not be found. The API returned this HTTP response:\n\n%s",
            $name,
            (string) $exception->getResponse()
        );

        $e = new self($message);

        $e->name = $name;
        $e->response = $exception->getResponse();
        $e->request = $exception->getRequest();

        return $e;
    }
}
